Contributing — Cohen3 0.8.0 documentation

# Contributing

Contributions are welcome, and they are greatly appreciated! Every little bit helps, and credit will always be given.

- 1. Types of Contributions
  - 1.1. Fix Cohen3 backends (plugin)
  - 1.2. Add more tests
  - 1.3. Report Bugs
  - 1.4. Fix Bugs
  - 1.5. Implement Features
  - 1.6. Write Documentation
  - 1.7. Submit Feedback
- 2. Setting Up the Code for Local Development
- 3. Contributor Guidelines
  - 3.1. Pull Request Guidelines
  - 3.2. Coding Standards
  - 3.3. Docstrings